Crate cumulus_client_consensus_proposer

Crate cumulus_client_consensus_proposer 

The Cumulus ProposerInterface is an extension of the Substrate ProposerFactory for creating new parachain blocks.

This utility is designed to be composed within any collator consensus algorithm.

Structs

Error
Errors that can occur when proposing a parachain block.

Traits

ProposerInterface
An interface for proposers.

Type Aliases

ProposalOf
A type alias for easily referring to the type of a proposal produced by a specific ProposerInterface.